Index: tests/ChecksumTest.cpp |
diff --git a/tests/ChecksumTest.cpp b/tests/ChecksumTest.cpp |
index 3658bd771ee27c666c1e59e0fdc0a1b9dc14cbc5..0302ea98861c1a91df65e38fd5a54313d1ed2a21 100644 |
--- a/tests/ChecksumTest.cpp |
+++ b/tests/ChecksumTest.cpp |
@@ -32,8 +32,8 @@ DEF_TEST(Checksum, r) { |
for (size_t i = 0; i < SK_ARRAY_COUNT(kAlgorithms); ++i) { |
const algorithmProc algorithm = kAlgorithms[i]; |
- // Hash of NULL is always 0. |
- ASSERT(algorithm(NULL, 0) == 0); |
+ // Hash of nullptr is always 0. |
+ ASSERT(algorithm(nullptr, 0) == 0); |
const uint32_t hash = algorithm(data, kBytes); |
// Should be deterministic. |